[−][src]Crate datetime
Modules
| convenience | Adds convenience functions to some structs. |
| fmt | Datetime-to-string routines. |
| zone | Datetimes with a variable UTC offset, and time zone calculations. |
Structs
| Duration | A duration is a length of time on the timeline, irrespective of time zone or calendar format, with millisecond precision. |
| Instant | An instant is an exact point on the timeline, irrespective of time zone or calendar format, with millisecond precision. |
| LocalDate | A local date is a day-long span on the timeline, without a time zone. |
| LocalDateTime | A local date-time is an exact instant on the timeline, without a time zone. |
| LocalTime | A local time is a time on the timeline that recurs once a day, without a time zone. |
| Offset | |
| OffsetDateTime | |
| TimeZone | A time zone, which here is a list of timespans, each containing a fixed offset for the current location’s time from UTC. |
| Year | A single year. |
| YearMonth | A month-year pair. |
| ZonedDateTime |
Enums
| Month | A month of the year, starting with January, and ending with December. |
| Weekday | A named day of the week. |
Traits
| DatePiece | The date piece trait is used for date and time values that have date components of years, months, and days. |
| ISO | |
| TimePiece | The time piece trait is used for date and time values that have time components of hours, minutes, and seconds. |
Functions
| sys_timezone | Attempts to determine the system’s current time zone. There’s no
guaranteed way to do this, so this function returns |