pub struct DateTimeBuilder { /* private fields */ }Expand description
An intermediate builder for DateTime.
Implementations
Sourceimpl DateTimeBuilder
impl DateTimeBuilder
Sourcepub const fn hms(self, hour: u8, minute: u8, second: u8) -> Self
pub const fn hms(self, hour: u8, minute: u8, second: u8) -> Self
Attach an hour, minute, and second to the datetime.
Sourcepub const fn tz(self, tz: TimeZoneRef<'static>) -> TzResult<Self>
Available on crate feature tz only.
pub const fn tz(self, tz: TimeZoneRef<'static>) -> TzResult<Self>
tz only.Attach a timezone to the datetime.
This method assumes that the timezone modifies the underlying timestamp; in other words, the YMD/HMS specified to the date and time builder should be preserved, and the time zone’s offset applied to the underlying timestamp to preserve the date and time on the wall clock.