Struct datetime::Duration [] [src]

pub struct Duration {
    // some fields omitted
}

A duration is a length of time on the timeline, irrespective of time zone or calendar format, with millisecond precision.

Methods

impl Duration
[src]

fn zero() -> Duration

Create a new zero-length duration.

fn of(seconds: i64) -> Duration

Create a new duration that’s the given number of seconds long.

fn of_ms(seconds: i64, milliseconds: i16) -> Duration

Create a new duration that’s the given number of seconds and milliseconds long.

fn lengths(&self) -> (i64, i16)

Return the seconds and milliseconds portions of the duration as a 2-element tuple.