Struct datetime::LocalDateTime [] [src]

pub struct LocalDateTime {
    // some fields omitted
}

A local date-time is an exact instant on the timeline, without a time zone.

Methods

impl LocalDateTime
[src]

fn from_instant(instant: Instant) -> LocalDateTime

Computes a complete date-time based on the values in the given Instant parameter.

fn at(seconds_since_1970_epoch: i64) -> LocalDateTime

Computes a complete date-time based on the number of seconds that have elapsed since midnight, 1st January, 1970, setting the number of milliseconds to 0.

fn at_ms(seconds_since_1970_epoch: i64, millisecond_of_second: i16) -> LocalDateTime

Computes a complete date-time based on the number of seconds that have elapsed since midnight, 1st January, 1970,

fn new(date: LocalDate, time: LocalTime) -> LocalDateTime

Creates a new local date time from a local date and a local time.

fn date(&self) -> LocalDate

Returns the date portion of this date-time stamp.

fn time(&self) -> LocalTime

Returns the time portion of this date-time stamp.

fn now() -> LocalDateTime

Creates a new date-time stamp set to the current time.

fn to_instant(&self) -> Instant

fn add_seconds(&self, seconds: i64) -> LocalDateTime