YearMonth

Struct YearMonth 

pub struct YearMonth {
    pub year: Year,
    pub month: Month,
}
A month-year pair.

Fields

year: Yearmonth: Month

Implementations

Source

impl YearMonth

pub fn day_count(&self) -> i8

Returns the number of days in this month. This can be definitely known, as the paired year determines whether it’s a leap year, so there’s no chance of being caught out by February.

Examples
use datetime::Year;
use datetime::Month::February;

assert_eq!(Year(2000).month(February).day_count(), 29);
assert_eq!(Year(1900).month(February).day_count(), 28);
pub fn days<S: DaySpan>(&self, span: S) -> MonthDays

Returns an iterator over a continuous span of days in this month, returning LocalDate values.

Examples
use datetime::Year;
use datetime::Month::September;

let ym = Year(1999).month(September);
assert_eq!(ym.days(..).count(), 30);
assert_eq!(ym.days(10 ..).count(), 21);
assert_eq!(ym.days(10 .. 20).count(), 10);
assert_eq!(ym.days(.. 20).count(), 19);
pub fn day(&self, day: i8) -> Result<LocalDate, Error>

Returns a LocalDate based on the day of this month.

This is just a short-cut for the LocalDate::ymd constructor.