pub trait TimePiece {
// Required methods
fn hour(&self) -> i8;
fn minute(&self) -> i8;
fn second(&self) -> i8;
fn millisecond(&self) -> i16;
}Expand description
The time piece trait is used for date and time values that have time components of hours, minutes, and seconds.
Required Methods
Sourcefn millisecond(&self) -> i16
fn millisecond(&self) -> i16
The millisecond of the second.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".