Module datetime::zone
[−]
[src]
Datetimes with a variable UTC offset, and time zone calculations.
Modules
| runtime |
Structs
| FixedTimespan |
An individual timespan with a fixed offset. |
| FixedTimespanSet |
A set of timespans, separated by the instances at which the timespans change over. There will always be one more timespan than transitions. |
| StaticTimeZone | |
| TimeZone |
A time zone, which here is a list of timespans, each containing a fixed offset for the current location’s time from UTC. |
| ZonedDateTime |
Enums
| LocalTimes |
The result of converting a local time to a zoned time with the same
time components. See |
| TimeType |
The “type” of time that a transition is specified in. |
| TimeZoneSource |