Trait datetime::TimePiece
[−]
[src]
pub trait TimePiece {
fn hour(&self) -> i8;
fn minute(&self) -> i8;
fn second(&self) -> i8;
fn millisecond(&self) -> i16;
}The time piece trait is used for date and time values that have time components of hours, minutes, and seconds.
Required Methods
fn hour(&self) -> i8
The hour of the day.
fn minute(&self) -> i8
The minute of the hour.
fn second(&self) -> i8
The second of the minute.
fn millisecond(&self) -> i16
The millisecond of the second.
Implementors
impl TimePiece for LocalTimeimpl TimePiece for LocalDateTimeimpl TimePiece for OffsetDateTimeimpl<'a> TimePiece for ZonedDateTime<'a>